@@ -16,11 +16,11 @@ Artifactory::Client - Perl client for Artifactory REST API
 
 =head1 VERSION
 
-Version 0.1.6
+Version 0.1.7
 
 =cut
 
-our $VERSION = '0.1.6';
+our $VERSION = '0.1.7';
 
 =head1 SYNOPSIS
 
@@ -401,6 +401,19 @@ sub retrieve_latest_artifact {
     }
 }
 
+=head2 retrieve_build_artifacts_archive( $payload )
+
+Takes payload (hashref) then retrieve build artifacts archive.
+
+=cut
+
+sub retrieve_build_artifacts_archive {
+    my ( $self, $payload ) = @_;
+    my ( $artifactory, $port ) = $self->_unpack_attributes( 'artifactory', 'port' );
+    my $url = "$artifactory:$port/artifactory/api/archive/buildArtifacts";
+    return $self->post( $url, "Content-Type" => 'application/json', Content => to_json( $payload ) );
+}
+
 =head2 deploy_artifact( path => $path, properties => { key => [ values ] }, content => $content )
 
 Takes path, properties and content then deploys artifact.  Note that properties are a hashref with key-arrayref pairs,
